@@ -47,7 +47,7 @@ class DashboardsService(
     def duplicate(
         self, dashboard_id: int, new_name: Optional[str] = None
     ) -> SimpleNamespace:
-        """Duplicate a dashboard and all its queries with `new_name`"""
+        """Duplicate a dashboard and all its widgets with `new_name`"""
         current = self.get(dashboard_id)
 
         if new_name is None:
